# Diary
This is a text-based diary, inspired by [khal](https://github.com/pimutils/khal).
Journal entries are stored in text files.

## Quickstart

1. Set the EDITOR environment variable to your favourite text editor:
    ```
    export EDITOR=vim
    ```

2. Run the diary, with the folder for the text files as first argument:
    ```
    diary ~/.diary
    ```

   Instead of this, you can also set the environment variable `DIARY_DIR` to
   the desired directory. If both an argument and the environment variable are
   given, the argument takes precedence.

   The text files in this folder will be named `yyy-mm-dd`.

3. Use the keypad or VIM-like shortcuts to move between dates:

    ```
    e, Enter  edit current entry
    d, x      delete current entry

    t         jump to today
    f         jump to or find specific day

    j, down   go forward by 1 week
    k, up     go backward by 1 week
    h, left   go left by 1 day
    l, right  go right by 1 day
    J         go forward by 1 month
    K         go backward by 1 month

    N         go to the previous journal entry
    n         go to the next journal entry
    g         go to start of journal
    G         go to end of journal

    s, S      sync selected day/Month with CalDAV server
    i         import entries from .ics file
    E         export entries to .ics file

    q         quit the program
    ```

## Detailed Usage, Configuration and End-User Documentation
See [man diary](https://diary.in0rdr.ch/man) for the complete documentation.

Demo and Keybinding Cheat Sheet available at https://diary.in0rdr.ch

## Install from Package
Pre-built packages can be installed from the [Open Build Service
(OBS)](https://software.opensuse.org/download.html?project=home%3Ain0rdr&package=diary)
* Install the `diary` package for a stable release
* Install the `diary-nightly` build to use a more recent but possibly unstable
  version from the master branch

### Arch Linux OBS Repository Bug
The Arch Linux repository on the OBS is broken, see
[#69](https://github.com/in0rdr/diary/issues/69) and
[#9953](https://github.com/openSUSE/open-build-service/issues/9953).

To use the repository on Arch Linux, use `downloadcontent.opensuse.org` instead
of the [suggested](https://software.opensuse.org/download.html?project=home%3Ain0rdr&package=diary)
name `download.opensuse.org` in the `/etc/pacman.conf`:

```
[home_in0rdr_Arch]
Server = https://downloadcontent.opensuse.org/repositories/home:/in0rdr/Arch/$arch
```

## Build from Source
1. Define [OAuth2 application credentials](https://developers.google.com/identity/protocols/oauth2)
   if CalDAV sync should be effective:

   ```
   export GOOGLE_OAUTH_CLIENT_ID=""
   export GOOGLE_OAUTH_CLIENT_SECRET=""
   ```

   Alternatively, leave these two variables unset and define the
   clientid/secret in the configuration file at run-time (see diary man page).

2. The compilation step requires development libraries for `ncurses`, `libcurl`
   and `liblttng-ust`. These packages might have a slightly different naming
   scheme depending on the distribution. To compile, run:

   ```
   make
   ```

   Note: for \*BSD users run gmake.

3. Install the binary (optional):

   ```
   sudo make install
   ```

   By default this will copy the binary to `/usr/local/bin`. To use a different
   path prefix, type `sudo make PREFIX=/usr install` to use `/usr/bin` for example.
   You can uninstall diary with `sudo make uninstall`.

## OBS Build Documentation
[./docs/OBS.md](./docs/OBS.md)

## Test Documentation
[./docs/TESTING.md](./docs/TESTING.md)

## Contributors
All source code is available in this repository. Contributions are always
welcome!

For a list of contributors see the [AUTHORS.md](./AUTHORS.md).

## Community and Support
For question and support visit
[#diary/libera](https://web.libera.chat/gamja/#diary) on IRC.

## License
This work uses the MIT License. See [LICENSE](./LICENSE) for details.

